@@ -28,24 +28,21 @@ from typing import Any
 from typing import Optional
 from typing import Type
 from typing import TypeVar
-from typing import Union
 
 import aiohttp
-from atoot import MastodonAPI
-from atoot import MastodonError
+from minimal_activitypub.client_2_server import ActivityPub
+from minimal_activitypub.client_2_server import ActivityPubError
 from rich import print as rprint
 from rich.logging import RichHandler
-from urllib3.util import parse_url
-from urllib3.util import Url
 
-from . import USER_AGENT
+from . import __display_name__
+
 
 BC = TypeVar("BC", bound="BotConfig")
 ConfigClass = TypeVar("ConfigClass", bound="Configuration")
 MC = TypeVar("MC", bound="MastodonConfig")
-MU = TypeVar("MU", bound="MastodonUser")
 
-logger = logging.getLogger("MastodonAmnesia")
+logger = logging.getLogger(__display_name__)
 
 
 @dataclass
@@ -75,12 +72,16 @@ class BotConfig:
             config = {}
 
         self.log_level = config.get("log_level", "WARN")
-        logging.basicConfig(
-            level=self.log_level,
-            format="%(name)s[%(process)d] %(levelname)s %(message)s",
+
+        std_out_formatter = logging.Formatter(
+            "%(name)s[%(process)d] %(levelname)s %(message)s",
             datefmt="%H:%M:%S",
-            handlers=[RichHandler()],
         )
+        std_out_handler = RichHandler()
+        std_out_handler.setFormatter(std_out_formatter)
+        std_out_handler.setLevel(self.log_level)
+        logger.addHandler(std_out_handler)
+
         self.delete_after = config.get("delete_after", None)
         self.skip_deleting_bookmarked = config.get("skip_deleting_bookmarked")
         self.skip_deleting_faved = config.get("skip_deleting_faved")
@@ -253,39 +254,13 @@ class BotConfig:
             sys.exit(1)
 
 
-@dataclass
-class MastodonUser:
-    """Dataclass holding information about the mastodon user we use to
-    login."""
-
-    email: str
-    user_name: str
-    access_token: str
-    account_id: int
-
-    def __init__(self: MU, user_info: Optional[dict[str, Any]]) -> None:
-        if not user_info:
-            user_info = {}
-
-        self.email = user_info.get("email", None)
-        self.user_name = user_info.get("user_name", None)
-        self.access_token = user_info.get("access_token", None)
-
-        if not self.email:
-            self.email = input("[..] Enter email address for Mastodon account: ")
-
-
 @dataclass
 class MastodonConfig:
     """Dataclass holding configuration values for Mastodon settings."""
 
     instance: str
-    user_info: MastodonUser
-    client_id: str
-    client_secret: str
-    mastodon: MastodonAPI
+    access_token: str
 
-    # def __init__(self: MC, mastodon_ini: Optional[dict[str, Any]]) -> None:
     @classmethod
     async def load_mastodon_config(
         cls: Type[MC], mastodon_ini: Optional[dict[str, Any]]
@@ -293,95 +268,48 @@ class MastodonConfig:
         """Loads Mastodon configuration from file and returns a MastodonConfig
         class instance."""
 
+        logger.debug(
+            "MastodonConfig.load_mastodon_config - mastodon_ini: %s", mastodon_ini
+        )
+
         if not mastodon_ini:
             mastodon_ini = {}
 
         base_url = mastodon_ini.get("base_url", None)
-        parsed_url: Optional[Url] = None
-        if base_url:
-            parsed_url = parse_url(url=base_url)
-
         instance = mastodon_ini.get("instance", None)
-        if instance is None and parsed_url:
-            instance = parsed_url.hostname
-
-        client_id = mastodon_ini.get("client_id", None)
-        client_secret = mastodon_ini.get("client_secret", None)
-        client_access_token = mastodon_ini.get("client_access_token", None)
-        if client_secret is None and client_access_token:
-            client_secret = client_access_token
+        if instance is None and base_url:
+            instance = base_url
 
         if not instance:
-            entered_instance = input(
+            instance = input(
                 "[..] Enter instance (domain name) for Mastodon account host: "
             )
-            instance = parse_url(url=entered_instance).hostname
 
-        user_info = MastodonUser(mastodon_ini.get("user_info", None))
+        access_token = mastodon_ini.get("access_token", None)
+
+        user_info = mastodon_ini.get("user_info", None)
+        if not access_token and user_info:
+            access_token = user_info.get("access_token", None)
 
         try:
-            if not user_info.access_token:
+            if not access_token:
+                user_name = input("[..] Enter user for your Fediverse account: ")
+                password = input("[..] Enter password for your Fediverse account: ")
+
                 async with aiohttp.ClientSession() as session:
-                    if not (client_id and client_secret):
-                        client_id, client_secret = await MastodonAPI.create_app(
-                            client_name=USER_AGENT,
-                            client_website="https://codeberg.org/MarvinsMastodonTools/mastodonamnesia",
-                            instance=instance,
-                            session=session,
-                        )
-                    mastodon = await MastodonAPI.create(
-                        instance=instance,
-                        client_id=client_id,
-                        client_secret=client_secret,
-                    )
-
-                    password = input("[..] Enter password for Mastodon account: ")
-
-                    user_info.access_token = await mastodon.login(
-                        session=session,
-                        username=user_info.email,
+                    access_token = await ActivityPub.get_auth_token(
+                        instance_url=instance,
+                        username=user_name,
                         password=password,
-                        instance=instance,
-                        client_id=client_id,
-                        client_secret=client_secret,
+                        session=session,
                     )
 
-                    await mastodon.close()
-
-            mastodon = await MastodonAPI.create(
-                access_token=user_info.access_token,
-                instance=instance,
-            )
-            userinfo = await mastodon.verify_account_credentials()
-
-            user_info.user_name = userinfo.get("username")
-            user_info.account_id = userinfo.get("id")
-        except MastodonError as mastodon_error:
-            rprint(f"! Error when setting up Mastodon connection: {mastodon_error}")
+        except ActivityPubError as error:
+            rprint(f"! Error when setting up Fediverse connection: {error}")
             rprint("! Cannot continue. Exiting now.")
             sys.exit(1)
 
-        return cls(
-            instance=instance,
-            user_info=user_info,
-            client_id=client_id,
-            client_secret=client_secret,
-            mastodon=mastodon,
-        )
-
-    def get_dict(
-        self: MC,
-    ) -> dict[str, Union[str, int, bool, dict[str, Union[str, int]]]]:
-        """Returns values of MastodonConfig instance as doct.
-
-        Only includes value that need to be saved
-        """
-        return {
-            "instance": self.instance,
-            "user_info": asdict(self.user_info),
-            "client_id": self.client_id,
-            "client_secret": self.client_secret,
-        }
+        return cls(instance=instance, access_token=access_token)
 
 
 @dataclass
@@ -389,7 +317,7 @@ class Configuration:
     """Dataclass to hold all settings for tootbot."""
 
     bot: BotConfig
-    mastodon_config: MastodonConfig
+    mastodon: MastodonConfig
 
     @classmethod
     async def load_config(
@@ -397,23 +325,28 @@ class Configuration:
     ) -> ConfigClass:
         """Loads configuration from file and returns a Configuration class
         instance."""
-        config: dict[str, Any] = {"Bot": None, "Mastodon": None}
-
         if os.path.exists(config_file_name):
             with open(file=config_file_name, encoding="UTF-8") as config_file:
-                config = json.load(config_file)
+                loaded_config = json.load(config_file)
+        else:
+            loaded_config = {}
 
+        mastodon_ini = loaded_config.get("mastodon")
+        if not mastodon_ini:
+            mastodon_ini = loaded_config.get("Mastodon")
         mastodon_config = await MastodonConfig.load_mastodon_config(
-            config.get("Mastodon")
+            mastodon_ini=mastodon_ini
         )
-        bot = BotConfig(config.get("Bot"))
 
-        config = {
-            "Bot": asdict(bot),
-            "Mastodon": mastodon_config.get_dict(),
-        }
+        bot_ini = loaded_config.get("bot")
+        if not bot_ini:
+            bot_ini = loaded_config.get("Bot")
+        bot = BotConfig(config=bot_ini)
+
+        config_instance = cls(bot=bot, mastodon=mastodon_config)
+        config_dict = asdict(config_instance)
         with open(file=config_file_name, mode="w", encoding="UTF-8") as config_file:
-            json.dump(config, config_file, indent=4)
-            logger.debug("Saved config: %s", config)
+            json.dump(config_dict, config_file, indent=4)
+            logger.debug("Configuration.load_config - Saved config: %s", config_dict)
 
-        return cls(bot=bot, mastodon_config=mastodon_config)
+        return config_instance
